@@ -172,11 +172,15 @@ SEXP glue_(SEXP x, SEXP f, SEXP open_arg, SEXP close_arg) {
   }
 
   if (state == delim) {
+    free(str);
     Rf_error("Expecting '%s'", close);
   }
 
   free(str);
 
+  out = resize(out, k);
+
   UNPROTECT(1);
-  return resize(out, k);
+
+  return out;
 }
