@@ -3,11 +3,6 @@
 #include <stdlib.h>
 #include <string.h> // for strlen(), strchr(), strncpy()
 
-const char* skip(const char* s, const char* delim) {
-  while (strchr(delim, s[0])) s++;
-  return s;
-}
-
 SEXP trim_(SEXP x) {
   size_t len = LENGTH(x);
 
@@ -85,14 +80,13 @@ SEXP trim_(SEXP x) {
         i += 2;
         continue;
       } else if (new_line) {
-        const char* after = skip(xx + i, "\t ");
-        const size_t skipped = after - (xx + i);
+        size_t skipped = strspn(xx + i, "\t ");
         /*
          * if the line consists only of tabs and spaces, and if the line is
          * shorter than min_indent, copy the entire line and proceed to the
          * next
          */
-        if (after[0] == '\n' && skipped < min_indent) {
+        if (*(xx + i + skipped) == '\n' && skipped < min_indent) {
           strncpy(str + j, xx + i, skipped);
           i += skipped;
           j += skipped;
